import os
import unittest
from crypto_qr_codes.qr import create_qr_code


class TestQR(unittest.TestCase):

    def test_create_qr_code(self):
        crypto_currency = "bitcoin"
        crypto_address = "1BvBMSEYstWetqTFn5Au4m4GFg7xJaNVN2"
        amount = "0.001"
        message = "Payment"
        filename = "test_qr"

        result = create_qr_code(crypto_currency, crypto_address, amount, label, message, filename)
        self.assertTrue(result)

        img_path = os.path.join(os.getcwd(), "qr_codes", f"{filename}.png")
        self.assertTrue(os.path.isfile(img_path))

        os.remove(img_path)


    def test_create_qr_code_defaults(self):
        crypto_currency = "bitcoin"
        crypto_address = "1BvBMSEYstWetqTFn5Au4m4GFg7xJaNVN2"

        result = create_qr_code(crypto_currency, crypto_address)
        self.assertTrue(result)

        img_path = os.path.join(os.getcwd(), "qr_codes", "output.png")
        self.assertTrue(os.path.isfile(img_path))

        os.remove(img_path)


if __name__ == '__main__':
    unittest.main()



import qrcode
import os


def create_qr_code(crypto_currency, crypto_address, amount=0, message='', filename="output"):
    """
    Create a QR code for a cryptocurrency address.

    Args:
        crypto_currency (str): The cryptocurrency symbol.
        crypto_address (str): The cryptocurrency address.
        amount (float, optional): The amount to be paid.
        message (str, optional): A message for the payment.
        filename (str, optional): The name of the file to save the QR code. Defaults to "output".

    Returns:
        str: The full path of the saved QR code image.
    """
    data = f"{crypto_currency}:{crypto_address}?amount={amount}&label=CryptoWallet.com&message={message}"
    try:
        # Create a QR code using the specified data
        qr = qrcode.QRCode(
            version=1,
            box_size=10,
            border=5
        )
        qr.add_data(data)
        qr.make(fit=True)
        img = qr.make_image(fill_color="black", back_color="white")

        # Save the QR code image
        img_path = os.path.join(os.getcwd(), "qr_codes")
        os.makedirs(img_path, exist_ok=True)
        filename = f"{filename}.png"
        full_path = os.path.join(img_path, filename)
        img.save(full_path)
    except Exception as error:
        return error

    return full_path



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="crypto-qr-codes",
    version="0.1.8",
    author="Robert Capla",
    author_email="robert.capla@icloud.com",
    description="A package for generating QR codes for various cryptocurrencies",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/RandoS-svk/CryptoQRGenerator",
    packages=["crypto_qr_codes"],
    install_requires=["qrcode"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
